# Changelog

## 0.8.2 (2026-01-13)

Full Changelog: [v0.8.1...v0.8.2](https://github.com/reminix-ai/reminix-python/compare/v0.8.1...v0.8.2)

### Features

* **api:** api update ([21350dc](https://github.com/reminix-ai/reminix-python/commit/21350dcb9e608eb569855b54c8f5ea5e33b7b4ea))

## 0.8.1 (2026-01-13)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/reminix-ai/reminix-python/compare/v0.8.0...v0.8.1)

### Features

* add streaming support for chat and invoke methods ([7ddc828](https://github.com/reminix-ai/reminix-python/commit/7ddc8286b7c81a30289ef23dff210bfc4dbdf8b1))
* add streaming support for chat and invoke methods ([42ed11e](https://github.com/reminix-ai/reminix-python/commit/42ed11e9358c7353c0e33e0623a19b9b38c7b064))


### Bug Fixes

* add return type annotation to async example ([69fb5ff](https://github.com/reminix-ai/reminix-python/commit/69fb5ffa2134b9fa06707b9f7d7538d5a92ec1a2))
* remove duplicate imports from merge conflict ([19fe51b](https://github.com/reminix-ai/reminix-python/commit/19fe51b1436e633644ee4a2bc139668f9273387d))

## 0.8.0 (2026-01-13)

Full Changelog: [v0.0.1...v0.8.0](https://github.com/reminix-ai/reminix-python/compare/v0.0.1...v0.8.0)

### Chores

* update SDK settings ([9afabab](https://github.com/reminix-ai/reminix-python/commit/9afabab1c4874729441334cb49d162dfcd21a9e2))
* update SDK settings ([9450d09](https://github.com/reminix-ai/reminix-python/commit/9450d096f52ad8d13531c4242d29498bcc07fa62))
